@@ -598,6 +598,15 @@ close_warn (char const *name)
   call_arg_warn ("close", name);
 }
 
+void
+close_diag (char const *name)
+{
+  if (ignore_failed_read_option)
+    close_warn (name);
+  else
+    close_error (name);
+}
+
 void
 exec_fatal (char const *name)
 {
@@ -648,6 +657,15 @@ open_warn (char const *name)
   call_arg_warn ("open", name);
 }
 
+void
+open_diag (char const *name)
+{
+  if (ignore_failed_read_option)
+    open_warn (name);
+  else
+    open_error (name);
+}
+
 void
 read_error (char const *name)
 {
@@ -680,6 +698,15 @@ read_warn_details (char const *name, off_t offset, size_t size)
 	 (unsigned long) size));
 }
 
+void
+read_diag_details (char const *name, off_t offset, size_t size)
+{
+  if (ignore_failed_read_option)
+    read_warn_details (name, offset, size);
+  else
+    read_error_details (name, offset, size);
+}
+
 void
 read_fatal (char const *name)
 {
@@ -711,6 +738,15 @@ readlink_warn (char const *name)
   call_arg_warn ("readlink", name);
 }
 
+void
+readlink_diag (char const *name)
+{
+  if (ignore_failed_read_option)
+    readlink_warn (name);
+  else
+    readlink_error (name);
+}
+
 void
 savedir_error (char const *name)
 {
@@ -723,6 +759,15 @@ savedir_warn (char const *name)
   call_arg_warn ("savedir", name);
 }
 
+void
+savedir_diag (char const *name)
+{
+  if (ignore_failed_read_option)
+    savedir_warn (name);
+  else
+    savedir_error (name);
+}
+
 void
 seek_error (char const *name)
 {
@@ -755,6 +800,15 @@ seek_warn_details (char const *name, off_t offset)
 	 STRINGIFY_BIGINT (offset, buf)));
 }
 
+void
+seek_diag_details (char const *name, off_t offset)
+{
+  if (ignore_failed_read_option)
+    seek_warn_details (name, offset);
+  else
+    seek_error_details (name, offset);
+}
+
 void
 symlink_error (char const *contents, char const *name)
 {
@@ -775,6 +829,15 @@ stat_warn (char const *name)
   call_arg_warn ("stat", name);
 }
 
+void
+stat_diag (char const *name)
+{
+  if (ignore_failed_read_option)
+    stat_warn (name);
+  else
+    stat_error (name);
+}
+
 void
 truncate_error (char const *name)
 {
