@@ -122,7 +122,8 @@ static struct fmttab {
   enum archive_format fmt;
 } const fmttab[] = {
   { "v7",      V7_FORMAT },
-  { "oldgnu",  OLDGNU_FORMAT },	
+  { "oldgnu",  OLDGNU_FORMAT },
+  { "ustar",   USTAR_FORMAT },
   { "posix",   POSIX_FORMAT },
 #if 0 /* not fully supported yet */
   { "star",    STAR_FORMAT },
@@ -218,7 +219,7 @@ enum
   USE_COMPRESS_PROGRAM_OPTION,
   VOLNO_FILE_OPTION,
   WILDCARDS_OPTION,
-  WILDCARDS_MATCH_SLASH_OPTION,
+  WILDCARDS_MATCH_SLASH_OPTION
 };
 
 /* If nonzero, display usage information and exit.  */
@@ -442,7 +443,8 @@ Archive format selection:\n\
                                      FMTNAME is one of the following:\n\
                                      v7        old V7 tar format\n\
                                      oldgnu    GNU format as per tar <= 1.12\n\
-                                     posix     POSIX 1003.1-2001 tar format\n\
+                                     ustar     POSIX 1003.1-1988 (ustar) format\n\
+                                     posix     POSIX 1003.1-2001 (pax) format\n\
                                      gnu       GNU format\n\
       --old-archive, --portability   same as --format=v7\n\
       --posix                        same as --format=posix\n\
@@ -479,7 +481,7 @@ Local file selection:\n\
 	     stdout);
 #if !MSDOS
       fputs (_("\
-  -N, --newer=DATE             only store files newer than DATE\n\
+  -N, --newer=DATE-OR-FILE     only store files newer than DATE-OR-FILE\n\
       --newer-mtime=DATE       compare date and time when data changed only\n\
       --after-date=DATE        same as -N\n"),
 	     stdout);
@@ -1274,7 +1276,7 @@ see the file named COPYING for details."));
     archive_format = DEFAULT_ARCHIVE_FORMAT;
 
   if (archive_format == GNU_FORMAT && getenv ("POSIXLY_CORRECT"))
-    archive_format = POSIX_FORMAT;
+    archive_format = POSIX_FORMAT; /*FIXME?*/
 
   if (volume_label_option && subcommand_option == CREATE_SUBCOMMAND)
     assert_format (FORMAT_MASK (OLDGNU_FORMAT)
@@ -1284,7 +1286,8 @@ see the file named COPYING for details."));
       || multi_volume_option
       || sparse_option)
     assert_format (FORMAT_MASK (OLDGNU_FORMAT)
-		   | FORMAT_MASK (GNU_FORMAT));
+		   | FORMAT_MASK (GNU_FORMAT)
+		   | FORMAT_MASK (POSIX_FORMAT));
   
   if (occurrence_option)
     {
@@ -1504,17 +1507,24 @@ main (int argc, char **argv)
     error (0, 0, _("Error exit delayed from previous errors"));
   if (ferror (stderr) || fclose (stderr) != 0)
     exit_status = TAREXIT_FAILURE;
-  exit (exit_status);
+  return exit_status;
 }
 
 void
-destroy_stat (struct tar_stat_info *st)
+tar_stat_init (struct tar_stat_info *st)
+{
+  memset (st, 0, sizeof (*st));
+}
+     
+void
+tar_stat_destroy (struct tar_stat_info *st)
 {
   free (st->orig_file_name);
   free (st->file_name);
   free (st->link_name);
   free (st->uname);
   free (st->gname);
+  free (st->sparse_map);
   memset (st, 0, sizeof (*st));
 }
 
