@@ -42,29 +42,6 @@ struct posix_header
 				/* 500 */
 };
 
-struct star_header
-{				/* byte offset */
-  char name[100];		/*   0 */
-  char mode[8];			/* 100 */
-  char uid[8];			/* 108 */
-  char gid[8];			/* 116 */
-  char size[12];		/* 124 */
-  char mtime[12];		/* 136 */
-  char chksum[8];		/* 148 */
-  char typeflag;		/* 156 */
-  char linkname[100];		/* 157 */
-  char magic[6];		/* 257 */
-  char version[2];		/* 263 */
-  char uname[32];		/* 265 */
-  char gname[32];		/* 297 */
-  char devmajor[8];		/* 329 */
-  char devminor[8];		/* 337 */
-  char prefix[131];		/* 345 */
-  char atime[12];               /* 476 */
-  char ctime[12];               /* 488 */
-                                /* 500 */
-};
-
 #define TMAGIC   "ustar"	/* ustar and a null */
 #define TMAGLEN  6
 #define TVERSION "00"		/* 00 and no null */
@@ -162,15 +139,17 @@ struct sparse_header
 struct oldgnu_header
 {				/* byte offset */
   char unused_pad1[345];	/*   0 */
-  char atime[12];		/* 345 */
-  char ctime[12];		/* 357 */
-  char offset[12];		/* 369 */
-  char longnames[4];		/* 381 */
+  char atime[12];		/* 345 Incr. archive: atime of the file */
+  char ctime[12];		/* 357 Incr. archive: ctime of the file */
+  char offset[12];		/* 369 Multivolume archive: the offset of
+				   the start of this volume */
+  char longnames[4];		/* 381 Not used */
   char unused_pad2;		/* 385 */
   struct sparse sp[SPARSES_IN_OLDGNU_HEADER];
 				/* 386 */
-  char isextended;		/* 482 */
-  char realsize[12];		/* 483 */
+  char isextended;		/* 482 Sparse file: Extension sparse header
+				   follows */
+  char realsize[12];		/* 483 Sparse file: Real size*/
 				/* 495 */
 };
 
@@ -210,6 +189,57 @@ struct oldgnu_header
 /* This file is a tape/volume header.  Ignore it on extraction.  */
 #define GNUTYPE_VOLHDR 'V'
 
+
+/* Jrg Schilling star header */
+
+struct star_header
+{				/* byte offset */
+  char name[100];		/*   0 */
+  char mode[8];			/* 100 */
+  char uid[8];			/* 108 */
+  char gid[8];			/* 116 */
+  char size[12];		/* 124 */
+  char mtime[12];		/* 136 */
+  char chksum[8];		/* 148 */
+  char typeflag;		/* 156 */
+  char linkname[100];		/* 157 */
+  char magic[6];		/* 257 */
+  char version[2];		/* 263 */
+  char uname[32];		/* 265 */
+  char gname[32];		/* 297 */
+  char devmajor[8];		/* 329 */
+  char devminor[8];		/* 337 */
+  char prefix[131];		/* 345 */
+  char atime[12];               /* 476 */
+  char ctime[12];               /* 488 */
+                                /* 500 */
+};
+
+#define SPARSES_IN_STAR_HEADER      4
+#define SPARSES_IN_STAR_EXT_HEADER  21
+
+struct star_in_header {
+  char fill[345];       /*   0  Everything that is before t_prefix */
+  char prefix[1];       /* 345  t_name prefix */
+  char fill2;           /* 346  */
+  char fill3[8];        /* 347  */
+  char isextended;      /* 355  */
+  struct sparse sp[SPARSES_IN_STAR_HEADER]; /* 356  */
+  char realsize[12];    /* 452  Actual size of the file */
+  char offset[12];      /* 464  Offset of multivolume contents */
+  char atime[12];       /* 476  */
+  char ctime[12];       /* 488  */
+  char mfill[8];        /* 500  */
+  char xmagic[4];       /* 508  "tar" */
+};
+
+struct star_ext_header {
+  struct sparse sp[SPARSES_IN_STAR_EXT_HEADER];
+  char isextended;
+};
+
+
+
 /* tar Header Block, overall structure.  */
 
 /* tar files are made in basic blocks of this size.  */
@@ -220,11 +250,19 @@ enum archive_format
   DEFAULT_FORMAT,		/* format to be decided later */
   V7_FORMAT,			/* old V7 tar format */
   OLDGNU_FORMAT,		/* GNU format as per before tar 1.12 */
-  POSIX_FORMAT,			/* restricted, pure POSIX format */
+  USTAR_FORMAT,                 /* POSIX.1-1988 (ustar) format */
+  POSIX_FORMAT,			/* POSIX.1-2001 format */
   STAR_FORMAT,                  /* Star format defined in 1994 */
   GNU_FORMAT			/* POSIX format with GNU extensions */
 };
 
+/* Information about a sparse file.  */
+struct sp_array
+  {
+    off_t offset;
+    size_t numbytes;
+  };
+
 struct tar_stat_info
 {
   char *orig_file_name;     /* name of file read from the archive header */
@@ -238,7 +276,16 @@ struct tar_stat_info
   unsigned int  devmajor;   /* device major number */
   char          *uname;     /* user name of owner */
   char          *gname;     /* group name of owner */
-  struct stat   stat;       /* regular filesystem stat */ 
+  struct stat   stat;       /* regular filesystem stat */
+
+  off_t archive_file_size;  /* Size of file as stored in the archive.
+			       Equals stat.st_size for non-sparse files */
+
+  size_t sparse_map_avail;  /* Index to the first unused element in
+			       sparse_map array. Zero if the file is
+			       not sparse */
+  size_t sparse_map_size;   /* Size of the sparse map */
+  struct sp_array *sparse_map; 
 };
 
 union block
@@ -248,6 +295,8 @@ union block
   struct star_header star_header;
   struct oldgnu_header oldgnu_header;
   struct sparse_header sparse_header;
+  struct star_in_header star_in_header;
+  struct star_ext_header star_ext_header;
 };
 
 /* End of Format description.  */
